@@ -31,6 +31,10 @@ def setup_menu(win):
     win.hex_menuitem.setCheckable(True)
     win.hex_menuitem.setChecked(win.hex)
     win.hex_menuitem.triggered.connect(win.on_view_hex)
+    win.regnames_menuitem = view_menu.addAction("DWARF register names")
+    win.regnames_menuitem.setCheckable(True)
+    win.regnames_menuitem.setChecked(win.dwarfregnames)
+    win.regnames_menuitem.triggered.connect(win.on_view_regnames)
     view_menu.addSeparator()
     win.sortcus_menuitem = view_menu.addAction("Sort CUs")
     win.sortcus_menuitem.setCheckable(True)
